@@ -85,7 +85,7 @@ def find_center_with_contours(img_binary, img_original, output_img, features) ->
         bounding_rect_size = width * height
 
         # Only consider elements with a certain amount of contour sides and a minimum size.
-        if contour_sides >= 6 and contour_sides <= 20 and bounding_rect_size >= 80:
+        if contour_sides >= 6 and contour_sides <= 20 and bounding_rect_size >= 75:
             box = cv2.boxPoints(bounding_rect)
             box = np.int0(box)
             
@@ -95,11 +95,11 @@ def find_center_with_contours(img_binary, img_original, output_img, features) ->
                 {"contour": contour, "x": x, "y": y, "bounding_rect": bounding_rect, "sides": contour_sides, "color": color}
             )
         else:
-            if contour_sides < 6:
+            if contour_sides < 5:
                 rejected_too_few_sides_cnt += 1
-            elif contour_sides > 20:
+            elif contour_sides > 22:
                 rejected_too_many_sides_cnt += 1
-            elif bounding_rect_size < 80:
+            elif bounding_rect_size < 50:
                 rejected_too_small_cnt += 1
 
     print(f"Rejected {rejected_too_few_sides_cnt + rejected_too_many_sides_cnt + rejected_too_small_cnt} of {len(contours[1:])} contours.")
@@ -167,7 +167,7 @@ def find_center_with_contours(img_binary, img_original, output_img, features) ->
         pair_offset_score = circle_pair["pair_offset"]
         closeness_to_hough_circle_score = circle_pair["closeness_to_hough_circle"] * 3
         side_score = circle_pair["total_sides"]
-        color_score = circle_pair["total_color"] * 200
+        color_score = circle_pair["total_color"] * 50
         score = pair_offset_score + closeness_to_hough_circle_score + side_score + color_score
         if best_score is None or score < best_score:
             best_score = score
@@ -209,10 +209,13 @@ def find_orientation_dot(features) -> None:
     _x2,_y2,w2,h2 = cv2.boundingRect(features["center_circle"])
     possible_orientation_dot_area = w * h
     center_circle_area = w2 * h2
+
+    possible_orientation_dot_index = 2
     while (possible_orientation_dot_area >= center_circle_area):
-        features["possible_fgc_elements"].pop(2)
+        possible_orientation_dot_index += 1
+        print("Removing possible_orientation_dot_area.")
         if len(features["possible_fgc_elements"]) > 2:
-            possible_orientation_dot = features["possible_fgc_elements"][2]
+            possible_orientation_dot = features["possible_fgc_elements"][possible_orientation_dot_index]
             _x,_y,w,h = cv2.boundingRect(possible_orientation_dot["contour"])
             possible_orientation_dot_area = w * h
         else:
@@ -223,6 +226,8 @@ def find_orientation_dot(features) -> None:
 def sanitize_data(features) -> None:
     """Try to get rid of all contours outside of the fgc by setting a max jump distance between contour distances to the center."""
 
+    print("Sanitizing data...")
+
     # Add furthest_distance_to_center entry to all contours
     for element in features["possible_fgc_elements"]:
         furthest_distance_to_center = 0
@@ -338,6 +343,8 @@ def get_data_from_rings(features):
     print(f"Getting data of { len(features['rings']) } rings...")
 
     for ring_id, ring in enumerate(features["rings"]):
+        
+        print(f"Ring #{ring_id} - Features:{len(features['rings'][ring_id])}")
 
         # Skip first two "rings" because they are the center circle and the orientation ring+dot
         if ring_id < 2:
